"""
The content of the string `nicknames` below was reproduced from `names.csv`
of https://github.com/carltonnorthern/nickname-and-diminutive-names-lookup

The original `names.csv` was licensed under Apache License 2.0.
Copyright @carltonnorthern.
A copy of the license can be found at http://www.apache.org/licenses/LICENSE-2.0
"""

__all__ = ["nicknames"]

nicknames = """
aaron,erin,ronnie,ron
abbigail,nabby,abby,gail,abbi,abbey
abednego,bedney
abel,ebbie,ab,abe,eb
abiel,ab
abigail,nabby,abby,gail
abijah,ab,bige
abner,ab
abraham,ab,abe
abram,ab,abe
absalom,app,ab,abbie
ada,addy
adaline,delia,lena,dell,addy,ada
addison,addie,addy
adela,della
adelaide,heidi,adele,dell,addy,della
adelbert,del,albert,delbert,bert
adele,addy,dell
adeline,delia,lena,dell,addy,ada
adelphia,philly,delphia,adele,dell,addy
adolphus,dolph,ado,adolph
adrian,rian
adriane,riane
adrienne,addie,rienne,enne
agatha,aggy
agnes,inez,aggy,nessa
aileen,lena,allie
alan,al
alanson,al,lanson
alastair,al
alazama,ali
albert,bert,al
alberta,bert,allie,bertie
aldo,al
aldrich,riche,rich
aleksandr,alex,alek
aleva,levy,leve
alex,al
alexander,alex,al,sandy,alec
alexandra,alex,sandy,alla,sandra
alexandria,drina,alexander,alla,sandra
alexis,lexi
alfonse,al
alfred,freddy,al,fred
alfreda,freddy,alfy,freda,frieda
algernon,algy
alice,lisa,elsie,allie
alicia,lisa,elsie,allie
aline,adeline
alison,ali,allie
alixandra,alix
allan,al
allen,al
allisandra,allie
allison,ali,allie
allyson,ally,allie
allyssa,ally,allie
almena,mena,allie
almina,minnie
almira,myra
alonzo,lon,al,lonzo
alphinias,alphus
althea,ally
alverta,virdie,vert
alyssa,lissia,al,ally
alzada,zada
amanda,mandy,manda
ambrose,brose
amelia,amy,mel,millie,emily
amos,moses
anastasia,ana,stacy
anderson,andy
andre,drea
andrea,drea,rea,andrew
andrew,andy,drew
andriane,ada,adri,rienne
angela,angel,angie
angelica,angie,angel
angelina,angel,angie,lina
ann,annie,nan
anna,anne,ann,annie,nan
anne,annie,ann,nan
annette,anna,nettie
annie,ann,anna
anselm,ansel,selma,anse,ance
anthony,ant,tony
antoinette,tony,netta,ann
antonia,tony,netta,ann
antonio,ant,tony
appoline,appy,appie
aquilla,quil,quillie
ara,belle,arry
arabella,ara,bella,arry,belle
arabelle,ara,bella,arry,belle
araminta,armida,middie,ruminta,minty
archibald,archie
archilles,kill,killis
ariadne,arie,ari
arielle,arie
aristotle,telly
arizona,onie,ona
arlene,arly,lena
armanda,mandy
armena,mena,arry
armilda,milly
arminda,mindie
arminta,minite,minnie
arnold,arnie
aron,erin,ronnie,ron
artelepsa,epsey
artemus,art
arthur,art
arthusa,thursa
arzada,zaddi
asahel,asa
asaph,asa
asenath,sene,assene,natty
ashley,ash,leah,lee
aubrey,bree
audrey,dee
august,gus
augusta,tina,aggy,gatsy,gussie
augustina,tina,aggy,gatsy,gussie
augustine,gus,austin,august
augustus,gus,austin,august
aurelia,ree,rilly,orilla,aurilla,ora
avarilla,rilla
azariah,riah,aze
bab,barby
babs,barby,barbara,bab
barbara,barby,babs,bab,bobbie
barbery,barbara
barbie,barbara
barnabas,barney
barney,barnabas
bart,bartholomew
bartholomew,bartel,bat,meus,bart,mees
barticus,bart
bazaleel,basil
bea,beatrice
beatrice,bea,trisha,trixie,trix
becca,beck
beck,becky
bedelia,delia,bridgit
belinda,belle,linda
bella,belle,arabella,isabella
benedict,bennie,ben
benjamin,benjy,jamie,bennie,ben,benny
benjy,benjamin
bernard,barney,bernie,berney
berney,bernie
bert,bertie,bob,bobby
bertha,bert,birdie,bertie
bertram,bert
bess,bessie
beth,betsy,betty,elizabeth
bethena,beth,thaney
beverly,bev
bezaleel,zeely
biddie,biddy
bill,william,billy,robert,willie,fred
billy,william,robert,fred
blanche,bea
bob,rob,robert
bobby,rob,bob
boetius,bo
brad,bradford,ford
bradford,ford,brad
bradley,brad
brady,brody
breanna,bree,bri
breeanna,bree
brenda,brandy
brian,bryan,bryant
brianna,bri
bridget,bridie,biddy,bridgie,biddie
brittany,britt
brittney,britt
broderick,ricky,brody,brady,rick
caitlin,cait,caity
caitlyn,cait,caity
caldonia,calliedona
caleb,cal
california,callie
calista,kissy
calpurnia,cally
calvin,vin,vinny,cal
cameron,ron,cam,ronny
camille,millie,cammie
campbell,cam
candace,candy,dacey
carlotta,lottie
carlton,carl
carmellia,mellia
carmelo,melo
carmon,charm,cammie,carm
carol,lynn,carrie,carolann,cassie,caroline,carole
carolann,carol,carole
caroline,lynn,carol,carrie,cassie,carole
carolyn,lynn,carrie,cassie
carrie,cassie
carthaette,etta,etty
casey,k.c.
casper,jasper
cassandra,sandy,cassie,sandra
cassidy,cassie,cass
caswell,cass
catherine,kathy,katy,lena,kittie,kit,trina,cathy,kay,cassie
cathleen,kathy,katy,lena,kittie,kit,trina,cathy,kay,cassie
cathy,kathy,cathleen,catherine
cecilia,cissy,celia
cedric,ced,rick,ricky
celeste,lessie,celia
celinda,linda,lynn,lindy
charity,chat
charles,charlie,chuck,carl,chick
charlie,charles,chuck
charlotte,char,sherry,lottie,lotta
chauncey,chan
cheryl,cher
chesley,chet
chester,chet
chet,chester
chick,charlotte,caroline,chuck
chloe,clo
chris,christina,christopher,christine
christa,chris
christian,chris,kit
christiana,kris,kristy,ann,tina,christy,chris,crissy
christiano,chris
christina,kris,kristy,tina,christy,chris,crissy
christine,kris,kristy,chrissy,tina,chris,crissy
christoph,chris
christopher,chris,kit
christy,crissy
cicely,cilla
cinderella,arilla,rella,cindy,rilla
cindy,cinderella
claire,clair,clare,clara
clara,clarissa
clare,clara
clarence,clare,clair
clarinda,clara
clarissa,cissy,clara
claudia,claud
cleatus,cleat
clement,clem
clementine,clement,clem
cliff,clifford,cliff
clifford,ford,cliff
clifton,tony,cliff
cole,colie
columbus,clum
con,conny
conrad,conny,con
constance,connie
cordelia,cordy,delia
corey,coco,cordy,ree
corinne,cora,ora
cornelia,nelly,cornie,nelia,corny,nelle
cornelius,conny,niel,corny,con
cory,coco,cordy,ree
courtney,curt,court
crystal,chris,tal,stal,crys
curtis,curt
cynthia,cintha,cindy
cyrenius,swene,cy,serene,renius,cene
cyrus,cy
dahl,dal
dalton,dahl,dal
daniel,dan,danny,dann
danielle,ellie,dani
danny,daniel
daphne,daph,daphie
darlene,lena,darry
david,dave,day,davey
deanne,ann,dee
debbie,deb,debra,deborah,debby
debby,deb
debora,deb,debbie,debby
deborah,deb,debbie,debby
debra,deb,debbie
deidre,deedee
delbert,bert,del
delia,fidelia,cordelia,delius
delilah,lil,lila,dell,della
deliverance,delly,dilly,della
della,adela,delilah,adelaide,dell
delores,lolly,lola,della,dee,dell
delpha,philadelphia
delphine,delphi,del,delf
demaris,dea,maris,mary
demerias,dea,maris,mary
democrates,mock
dennis,denny
dennison,denny
derrick,ricky,eric,rick
deuteronomy,duty
diana,dicey,didi,di
diane,dicey,didi,di
dicey,dicie
dick,rick,richard
dickson,dick
domenic,dom
dominic,dom
dominick,dom
donald,dony,donnie,don,donny
donovan,dony,donnie,don,donny
dorcus,darkey
dorinda,dorothea,dora
doris,dora
dorothea,doda,dora
dorothy,dortha,dolly,dot,dotty
dotha,dotty
dotty,dot
douglas,doug
drusilla,silla
duncan,dunk
earnest,ernestine,ernie
ebbie,eb
ebenezer,ebbie,eben,eb
eddie,ed
eddy,ed
edgar,ed,eddie,eddy
edith,edie,edye
edmond,ed,eddie,eddy
edmund,ed,eddie,ted,eddy,ned
edna,edny
eduardo,ed,eddie,eddy
edward,teddy,ed,ned,ted,eddy,eddie
edwin,ed,eddie,win,eddy,ned
edwina,edwin
edyth,edie,edye
edythe,edie,edye
egbert,bert,burt
eighta,athy
eileen,helen
elaine,lainie,helen
elbert,albert
elbertson,elbert,bert
eleanor,lanna,nora,nelly,ellie,elaine,ellen,lenora
eleazer,lazar
elena,helen
elias,eli,lee,lias
elijah,lige,eli
eliphalel,life
eliphalet,left
elisa,lisa
elisha,lish,eli
eliza,elizabeth
elizabeth,libby,lisa,lib,lizzy,lizzie,eliza,betsy,liza,betty,bessie,bess,beth,liz
ella,ellen
ellen,nellie,nell,helen
ellender,nellie,ellen,helen
ellie,elly
ellswood,elsey
elminie,minnie
elmira,ellie,elly,mira
elnora,nora
eloise,heloise,louise
elouise,louise
elsie,elsey
elswood,elsey
elvira,elvie
elwood,woody
elysia,lisa
elze,elsey
emanuel,manuel,manny
emeline,em,emmy,emma,milly,emily
emil,emily
emily,emmy,millie,emma,mel
emma,emmy
epaphroditius,dite,ditus,eppa,dyche,dyce
ephraim,eph
erasmus,raze,rasmus
eric,rick,ricky
ernest,ernie
ernestine,teeny,ernest,tina,erna
erwin,irwin
eseneth,senie
essy,es
estella,essy,stella
estelle,essy,stella
esther,hester,essie
eudicy,dicey
eudora,dora
eudoris,dossie,dosie
eugene,gene
eunice,nicie
euphemia,effie,effy
eurydice,dicey
eustacia,stacia,stacy
eva,eve
evaline,eva,lena,eve
evangeline,ev,evan,vangie
evelyn,evelina,ev,eve
experience,exie
ezekiel,zeke,ez
ezideen,ez
ezra,ez
faith,fay
felicia,fel,felix,feli
felicity,flick,tick
feltie,felty
ferdinand,freddie,freddy,ferdie,fred
ferdinando,nando,ferdie,fred
fidelia,delia
flo,florence
flora,florence
florence,flossy,flora,flo
floyd,lloyd
fran,frannie
frances,sis,cissy,frankie,franniey,fran,francie,frannie,fanny
francie,francine
francine,franniey,fran,frannie,francie
francis,fran,frankie,frank
frank,franklin
frankie,frank,francis
franklin,fran,frank
franklind,frank
freda,frieda
frederica,frederick,freddy
frederick,freddie,freddy,fritz,fred
fredericka,freddy,ricka,freda,frieda
frieda,freddie,freddy,fred
gabriel,gabe,gabby
gabriella,ella,gabby
gabrielle,ella,gabby
garrick,garri
genevieve,jean,eve,jenny
geoffrey,geoff,jeff
george,georgie
georgiana,georgia
gerald,gerry,jerry
geraldine,gerry,gerrie,jerry,dina
gerhardt,gay
gertie,gertrude,gert
gertrude,gertie,gert,trudy
gilbert,bert,gil,wilber
giovanni,gio
gloria,glory
governor,govie
greenberry,green,berry
greggory,gregg
gregory,greg,gory
gretchen,margaret
griselda,grissel
gum,monty
gus,gussie
gustavus,gus,gussie
gwen,wendy
gwendolyn,gwen,wendy
hamilton,ham
hannah,nan,nanny,anna
harold,hal,harry
harriet,hattie
harry,harold,henry
haseltine,hassie
heather,hetty
helen,lena,ella,ellen,ellie
helena,eileen,lena,nell,nellie,eleanor,elaine,ellen,aileen
helene,lena,ella,ellen,ellie
heloise,lois,eloise,elouise
henrietta,hank,etta,etty,retta,nettie
henry,hank,hal,harry
hephsibah,hipsie
hepsibah,hipsie
herbert,bert,herb
herman,harman,dutch
hermione,hermie
hester,hessy,esther,hetty
hezekiah,hy,hez,kiah
hiram,hy
honora,honey,nora,norry,norah
hopkins,hopp,hop
horace,horry
hortense,harty,tensey
hosea,hosey,hosie
howard,hal,howie
hubert,bert,hugh,hub
ian,john
ignatius,natius,iggy,nate,nace
ignatzio,naz,iggy,nace
immanuel,manuel,emmanuel
india,indie,indy
inez,agnes
iona,onnie
irene,rena
irvin,irving
irving,irv
irwin,erwin
isaac,ike,zeke
isabel,tibbie,bell,nib,belle,bella,nibby,ib,issy
isabella,tibbie,nib,belle,bella,nibby,ib,issy
isabelle,tibbie,nib,belle,bella,nibby,ib,issy
isadora,issy,dora
isaiah,zadie,zay
isidore,izzy
iva,ivy
ivan,john
jackson,jack
jacob,jaap,jake,jay
jacobus,jacob
jacqueline,jackie,jack
jahoda,hody,hodie,hoda
jakob,jake
james,jimmy,jim,jamie,jimmie,jem
jamie,james
jane,janie,jessie,jean,jennie
janet,jan,jessie
janice,jan
jannett,nettie
jasper,jap,casper
jayme,jay
jean,jane,jeannie
jeanette,jessie,jean,janet,nettie
jeanne,jane,jeannie
jebadiah,jeb
jedediah,dyer,jed,diah
jedidiah,dyer,jed,diah
jefferey,jeff
jefferson,sonny,jeff
jeffery,jeff
jeffrey,geoff,jeff
jehiel,hiel
jehu,hugh,gee
jemima,mima
jennet,jessie,jenny,jenn
jennifer,jennie,jenn,jen,jenny
jeremiah,jereme,jerry
jeremy,jezza,jez
jerita,rita
jerry,jereme,geraldine
jessica,jessie
jessie,jane,jess,janet
jim,jimmie
jincy,jane
jinsy,jane
joan,jo,nonie
joann,jo
joanna,hannah,jody,jo,joan
joanne,jo
jody,jo
joe,joey
johanna,jo
johannah,hannah,jody,joan,nonie
johannes,jonathan,john,johnny
john,jack,johnny,jock,ian
jonathan,john,nathan,jon,jonny,jonnie
jonathon,jon,jonny,jonnie
joseph,jody,jos,joe,joey
josephine,fina,jody,jo,josey,joey,josie
josetta,jettie
josey,josophine
joshua,jos,josh
josiah,jos
joyce,joy
juanita,nita,nettie
judah,juder,jude
judith,judie,juda,judy,judi,jude
judson,sonny,jud
judy,judith
julia,julie,jill
julian,jule
julias,jule
julie,julia,jule
june,junius
junior,junie,june,jr
justin,justus,justina
kaitlin,kait,kaitie
kaitlyn,kait,kaitie
kaitlynn,kait,kaitie
kameron,kam
karonhappuck,karon,karen,carrie,happy
kasey,k.c.
katarina,catherine,tina
kate,kay
katelin,kay,kate,kaye
katelyn,kay,kate,kaye
katherine,kathy,katy,lena,kittie,kaye,kit,trina,cathy,kay,kate,cassie
kathleen,kathy,katy,lena,kittie,kit,trina,cathy,kay,cassie
kathryn,kathy,katie
katy,kathy,katie
kayla,kay
kendall,ken,kenny
kendra,kenj,kenji,kay,kenny
kendrick,ken,kenny
kendrik,ken,kenny
kenneth,ken,kenny,kendrick
kenny,ken,kenneth
kent,ken,kenny,kendrick
keziah,kizza,kizzie
kim,kimberly,kimberley
kimberley,kim
kimberly,kim
kingsley,king
kingston,king
kit,kittie
kris,chris
kristel,kris
kristen,chris
kristin,chris
kristine,kris,kristy,tina,christy,chris,crissy
kristopher,chris,kris
kristy,chris
lafayette,laffie,fate
lamont,monty
laodicia,dicy,cenia
larry,laurence,lawrence
lauren,ren,laurie
laurence,lorry,larry,lon,lonny,lorne
laurinda,laura,lawrence
lauryn,laurie
laveda,veda
laverne,vernon,verna
lavina,vina,viney,ina
lavinia,vina,viney,ina
lavonia,vina,vonnie,wyncha,viney
lavonne,von
lawrence,lorry,larry,lon,lonny,lorne
leanne,lea,annie
lecurgus,curg
lemuel,lem
lena,ellen
lenora,nora,lee
leo,leon
leonard,lineau,leo,leon,len,lenny
leonidas,lee,leon
leonora,nora,nell,nellie
leonore,nora,honor,elenor
leroy,roy,lee,l.r.
leslie,les
lester,les
letitia,tish,titia,lettice,lettie
levi,lee
levicy,vicy
levone,von
lib,libby
lidia,lyddy
lil,lilly,lily
lillah,lil,lilly,lily,lolly
lillian,lil,lilly,lolly
lilly,lily,lil
lincoln,link
linda,lindy,lynn
lindy,lynn
lionel,leon
lisa,liz
littleberry,little,berry,l.b.
lizzie,liz
lois,lou,louise
lonzo,lon
lorenzo,loren
loretta,etta,lorrie,retta
lorraine,lorrie
lotta,lottie
lou,louis,lu
louis,lewis,louise,louie,lou
louisa,eliza,lou,lois
louise,eliza,lou,lois
louvinia,vina,vonnie,wyncha,viney
lucas,luke
lucia,lucy,lucius
lucias,luke
lucille,cille,lu,lucy,lou
lucina,sinah
lucinda,lu,lucy,cindy,lou
lucretia,creasey
lucy,lucinda
luella,lula,ella,lu
luke,lucas
lunetta,nettie
lurana,lura
luther,luke
lydia,lyddy
lyndon,lindy,lynn
mabel,mehitabel,amabel
mac,mc
mack,mac,mc
mackenzie,kenzy,mac,mack
maddison,maddie,maddi
maddy,madelyn,madeline,madge
madeline,maggie,lena,magda,maddy,madge
madeline,maddie,maddi
madie,madeline,madelyn
madison,mattie,maddy
maegen,meg
magdalena,maggie,lena
magdelina,lena,magda,madge
mahala,hallie
makayla,kayla
malachi,mally
malcolm,mac,mal,malc
malinda,lindy
manda,mandy
mandie,amanda
mandy,amanda
manerva,minerva,nervie,eve,nerva
manny,manuel
manoah,noah
manola,nonnie
manuel,emanuel,manny
marcus,mark
margaret,maggie,meg,peg,midge,margy,margie,madge,peggy,maggy,marge,daisy,margery,gretta,rita
margaretta,maggie,meg,peg,midge,margie,madge,peggy,marge,daisy,margery,gretta,rita
margarita,maggie,meg,metta,midge,greta,megan,maisie,madge,marge,daisy,peggie,rita,margo
marge,margery,margaret,margaretta
margie,marjorie,margie
marguerite,peggy
mariah,mary,maria
marian,marianna,marion
marie,mae
marietta,mariah,mercy,polly,may,molly,mitzi,minnie,mollie,mae,maureen,marion,marie,mamie,mary,maria
marilyn,mary
marion,mary
marissa,rissa
marjorie,margie
marjorie,margy,margie
marsha,marcie,mary
martha,marty,mattie,mat,patsy,patty
martin,marty
martina,tina
martine,tine
marv,marvin
marvin,marv
mary,mamie,molly,mae,polly,mitzi
masayuki,masa
mat,mattie
mathew,mat,maty
mathilda,tillie,patty
matilda,tilly,maud,matty
matthew,thys,matt,thias,mattie,matty
matthias,thys,matt,thias
maud,middy
maureen,mary
maurice,morey
mavery,mave
mavine,mave
maximillian,max
maxine,max
maxwell,max
may,mae
mckenna,ken,kenna,meaka
medora,dora
megan,meg
meghan,meg
mehitabel,hetty,mitty,mabel,hitty
melanie,mellie
melchizedek,zadock,dick
melinda,linda,mel,lynn,mindy,lindy
melissa,lisa,mel,missy,milly,lissa
mellony,mellia
melody,lodi
melvin,mel
melvina,vina
mercedes,merci,sadie,mercy
merv,mervin
mervyn,merv
micajah,cage
michael,micky,mike,micah,mick,mikey
micheal,mike,miky,mikey
michelle,mickey
mick,micky
mike,micky,mick,michael
mildred,milly
millicent,missy,milly
minerva,minnie
minnie,wilhelmina
miranda,randy,mandy,mira
miriam,mimi,mitzi,mitzie
missy,melissa
mitch,mitchell
mitchell,mitch
mitzi,mary,mittie,mitty
mitzie,mittie,mitty
monet,nettie
monica,monna,monnie
monteleon,monte
montesque,monty
montgomery,monty,gum
monty,lamont
morris,morey
mortimer,mort
moses,amos,mose,moss
muriel,mur
myrtle,myrt,myrti,mert
nadine,nada,deedee
nancy,ann,nan,nanny
naomi,omi
napoleon,nap,nappy,leon
natalie,natty,nettie
natasha,tasha,nat
nathan,nate,nat
nathaniel,than,nathan,nate,nat,natty
nelle,nelly
nelson,nels
newt,newton
nicholas,nick,claes,claas,nic,nicky,nico,nickie
nicodemus,nick,nic,nicky,nico,nickie
nicole,nole,nikki,cole
nikolas,nick,claes,nic,nicky,nico,nickie
nikole,nikki
nora,nonie
norbert,bert,norby
norbusamte,norbu
nowell,noel
obadiah,dyer,obed,obie,diah
obedience,obed,beda,beedy,biddie
obie,obediah
octavia,tave,tavia
odell,odo
olive,nollie,livia,ollie
oliver,ollie
olivia,nollie,livia,ollie
ollie,oliver
onicyphorous,cyphorus,osaforus,syphorous,one,cy,osaforum
orilla,rilly,ora
orlando,roland
orphelia,phelia
ossy,ozzy
oswald,ozzy,waldo,ossy
otis,ode,ote
pamela,pam
pandora,dora
parmelia,amelia,milly,melia
parthenia,teeny,parsuny,pasoonie,phenie
patience,pat,patty
patricia,tricia,pat,patsy,patty,patti
patrick,pate,peter,pat,patsy,paddy
patsy,patty
patty,patricia
paul,polly
paula,polly,lina
paulina,polly,lina
pauline,polly
peggy,peg
pelegrine,perry
penelope,penny
percival,percy
peregrine,perry
permelia,melly,milly,mellie
pernetta,nettie
persephone,seph,sephy
peter,pete,pate
petronella,nellie
pheney,josephine
pheriba,pherbia,ferbie
philadelphia,delphia
philander,fie
philetus,leet,phil
philinda,linda,lynn,lindy
philip,phil
philipina,phoebe,penie
phillip,phil
philly,delphia
philomena,menaalmena
phoebe,fifi
pinckney,pink
pleasant,ples
pocahontas,pokey
posthuma,humey
prescott,scotty,scott,pres
priscilla,prissy,cissy,cilla
providence,provy
prudence,prue,prudy
prudy,prudence
rachel,shelly
rafaela,rafa
ramona,mona
randolph,dolph,randy
raphael,ralph
ray,raymond
raymond,ray
reba,beck,becca
rebecca,beck,becca,reba,becky
reggie,reginald,reg
regina,reggie,gina
reginald,reggie,naldo,reg,renny
relief,leafa
reuben,rube
reynold,reginald
rhoda,rodie
rhodella,della
rhyna,rhynie
ricardo,rick,ricky
rich,dick,rick
richard,dick,dickon,dickie,dicky,rick,rich,ricky,richie
rick,ricky
ricky,dick,rich
robert,hob,hobkin,dob,rob,bobby,dobbin,bob
roberta,robbie,bert,bobbie,birdie,bertie
roderick,rod,erick,rickie,roddy
rodger,roge,bobby,hodge,rod,robby,rupert,robin
rodney,rod
roger,roge,bobby,hodge,rod,robby,rupert,robin
roland,rollo,lanny,orlando,rolly
ron,ronnie,ronny
ronald,naldo,ron,ronny,ronnie
ronny,ronald
rosa,rose
rosabel,belle,roz,rosa,rose
rosabella,belle,roz,rosa,rose
rosalinda,linda,roz,rosa,rose
rosalyn,linda,roz,rosa,rose
roscoe,ross
rose,rosie
roseann,rose,ann,rosie,roz
roseanna,rose,ann,rosie,roz
roseanne,ann
rosina,sina
roxane,rox,roxie
roxanna,roxie,rose,ann
roxanne,roxie,rose,ann
rudolph,dolph,rudy,olph,rolf
rudolphus,dolph,rudy,olph,rolf
russell,russ,rusty
ryan,ry
sabrina,brina
safieel,safie
salome,loomie
salvador,sal
samantha,sammy,sam,mantha
sammy,samuel
sampson,sam
samson,sam
samuel,sammy,sam
samyra,myra
sandra,sandy,cassandra
sandy,sandra
sanford,sandy
sarah,sally,sadie
sarilla,silla
savannah,vannie,anna
scott,scotty,sceeter,squat,scottie
sebastian,sebby,seb
selma,anselm
serena,rena
serilla,rilla
seymour,see,morey
shaina,sha,shay
sharon,sha,shay
sheila,cecilia
sheldon,shelly
shelton,tony,shel,shelly
sheridan,dan,danny,sher
sheryl,sher
shirley,sherry,lee,shirl
sibbilla,sybill,sibbie,sibbell
sidney,syd,sid
sigfired,sid
sigfrid,sid
sigismund,sig
silas,si
silence,liley
silvester,vester,si,sly,vest,syl
simeon,si,sion
simon,si,sion
smith,smitty
socrates,crate
solomon,sal,salmon,sol,solly,saul,zolly
sondra,dre,sonnie
sophia,sophie
sophronia,frona,sophia,fronia
stephan,steve
stephanie,stephen,stephie,annie,steph
stephen,steve,steph
steve,stevie
steven,steve,steph,stevie
stuart,stu
sue,susie,susan
sullivan,sully,van
sully,sullivan
susan,hannah,susie,sue,sukey,suzie
susannah,hannah,susie,sue,sukey
susie,suzie
suzanne,suki,sue,susie
sybill,sibbie
sydney,sid
sylvanus,sly,syl
sylvester,sy,sly,vet,syl,vester,si,vessie
tabby,tabitha
tabitha,tabby
tamarra,tammy
tanafra,tanny
tasha,tash,tashie
ted,teddy
temperance,tempy
terence,terry
teresa,terry
terry,terence
tess,teresa,theresa
tessa,teresa,theresa
thad,thaddeus
thaddeus,thad
theo,theodore
theodora,dora
theodore,theo,ted,teddy
theodosia,theo,dosia,theodosius
theophilus,ophi
theotha,otha
theresa,tessie,thirza,tessa,terry,tracy,tess,thursa
thom,thomas,tommy,tom
thomas,thom,tommy,tom
thomasa,tamzine
tiffany,tiff,tiffy
tilford,tillie
tim,timothy,timmy
timmy,timothy
timothy,tim,timmy
tina,christina
tobias,bias,toby
tom,thomas,tommy
tommy,thomas
tony,anthony
tranquilla,trannie,quilla
trisha,patricia
trix,trixie
trudy,gertrude
tryphena,phena
unice,eunice,nicie
uriah,riah
ursula,sulie,sula
valentina,felty,vallie,val
valentine,felty
valeri,val
valerie,val
vanburen,buren
vandalia,vannie
vanessa,essa,vanna,nessa
vernisee,nicey
veronica,vonnie,ron,ronna,ronie,frony,franky,ronnie
vic,vicki,vicky
vicki,vicky,victoria
vickie,victoria
vicky,victoria
victor,vic,vickie,vicky
victoria,torie,vic,vicki,tory,vicky
vijay,vij
vincent,vic,vince,vinnie,vin,vinny
vincenzo,vic,vinnie,vin,vinny,vince
vinson,vinny,vinnie,vin
viola,ola,vi
violetta,lettie
virginia,jane,jennie,ginny,virgy,ginger
vivian,vi,viv
waldo,ozzy,ossy
wallace,wally
wally,walt
walter,wally,walt
washington,wash
webster,webb
wendy,wen
wesley,wes
westley,west,wes,farmboy
wilber,will,bert
wilbur,willy,willie
wilda,willie
wilfred,will,willie,fred,wil
wilhelm,wil,willie
wilhelmina,mina,wilma,willie,minnie
will,bill,willie,wilbur,fred
william,willy,bell,bela,bill,will,billy,willie,wil
willie,william,fred
willis,willy,bill
wilma,william,billiewilhelm
wilson,will,willy,willie
winfield,field,winny,win
winifred,freddie,winnie,winnet
winnie,winnifred
winnifred,freddie,freddy,winny,winnie,fred
winny,winnifred
winton,wint
woodrow,woody,wood,drew
yeona,onie,ona
yoshihiko,yoshi
yulan,lan,yul
yvonne,vonna
zach,zachariah
zachariah,zachy,zach,zeke,zac,zack,zak,zakk
zachary,zachy,zach,zeke,zac,zack,zak,zakk
zachery,zachy,zach,zeke,zac,zack,zak,zakk
zebedee,zeb
zedediah,dyer,zed,diah
zephaniah,zeph
"""
